all: fix typos found by codespell

This commit is contained in:
Timo Rothenpieler 2025-08-01 22:43:23 +02:00
parent 8d439b2483
commit 262d41c804
303 changed files with 482 additions and 481 deletions

View file

@ -148,7 +148,7 @@
// static const uint16_t coef_hf[3] = { 5570, 3801, 1016 };
// static const uint16_t coef_sp[2] = { 5077, 981 };
const coeffs, align=4 // align 4 means align on 2^4 boundry
const coeffs, align=4 // align 4 means align on 2^4 boundary
.hword 4309 * 4, 213 * 4 // lf[0]*4 = v0.h[0]
.hword 5570, 3801, 1016, -3801 // hf[0] = v0.h[2], -hf[1] = v0.h[5]
.hword 5077, 981 // sp[0] = v0.h[6]

View file

@ -836,7 +836,7 @@ static void print_stats(AVFilterContext *ctx)
av_log(ctx, AV_LOG_INFO, "RMS peak dB: %f\n", LINEAR_TO_DB(sqrt(p->max_sigma_x2)));
if (s->measure_perchannel & MEASURE_RMS_TROUGH)
if (p->min_sigma_x2 != 1)
av_log(ctx, AV_LOG_INFO, "RMS trough dB: %f\n",LINEAR_TO_DB(sqrt(p->min_sigma_x2)));
av_log(ctx, AV_LOG_INFO, "RMS through dB: %f\n",LINEAR_TO_DB(sqrt(p->min_sigma_x2)));
if (s->measure_perchannel & MEASURE_CREST_FACTOR)
av_log(ctx, AV_LOG_INFO, "Crest factor: %f\n", p->sigma_x2 ? FFMAX(-p->nmin, p->nmax) / sqrt(p->sigma_x2 / p->nb_samples) : 1);
if (s->measure_perchannel & MEASURE_FLAT_FACTOR)
@ -896,7 +896,7 @@ static void print_stats(AVFilterContext *ctx)
av_log(ctx, AV_LOG_INFO, "RMS peak dB: %f\n", LINEAR_TO_DB(sqrt(max_sigma_x2)));
if (s->measure_overall & MEASURE_RMS_TROUGH)
if (min_sigma_x2 != 1)
av_log(ctx, AV_LOG_INFO, "RMS trough dB: %f\n", LINEAR_TO_DB(sqrt(min_sigma_x2)));
av_log(ctx, AV_LOG_INFO, "RMS through dB: %f\n", LINEAR_TO_DB(sqrt(min_sigma_x2)));
if (s->measure_overall & MEASURE_FLAT_FACTOR)
av_log(ctx, AV_LOG_INFO, "Flat factor: %f\n", LINEAR_TO_DB((min_runs + max_runs) / (min_count + max_count)));
if (s->measure_overall & MEASURE_PEAK_COUNT)

View file

@ -112,7 +112,7 @@ typedef struct ATempoContext {
// number of channels:
int channels;
// row of bytes to skip from one sample to next, across multple channels;
// row of bytes to skip from one sample to next, across multiple channels;
// stride = (number-of-channels * bits-per-sample-per-channel) / 8
int stride;

View file

@ -138,7 +138,7 @@ static void print_stats(AVFilterContext *ctx)
int peak_bin = BINS;
if (!p->nb_samples) {
av_log(ctx, AV_LOG_INFO, "No data, dynamic range not meassurable\n");
av_log(ctx, AV_LOG_INFO, "No data, dynamic range not measurable\n");
return;
}

View file

@ -734,7 +734,7 @@ static int load_data(AVFilterContext *ctx, int azim, int elev, float radius, int
AVComplexFloat *fft_in_r = NULL;
float *data_ir_l = NULL;
float *data_ir_r = NULL;
int offset = 0; /* used for faster pointer arithmetics in for-loop */
int offset = 0; /* used for faster pointer arithmetic in for-loop */
int i, j, azim_orig = azim, elev_orig = elev;
int ret = 0;
int n_current;
@ -954,7 +954,7 @@ fail:
av_freep(&data_hrtf_l); /* free temporary HRTF memory */
av_freep(&data_hrtf_r);
av_freep(&data_ir_l); /* free temprary IR memory */
av_freep(&data_ir_l); /* free temporary IR memory */
av_freep(&data_ir_r);
av_freep(&fft_out_l); /* free temporary FFT memory */

View file

@ -619,7 +619,7 @@ static int render_fontconfig(ShowCQTContext *s, AVFrame *tmp, char* font)
FcDefaultSubstitute(pat);
if (!FcConfigSubstitute(fontconfig, pat, FcMatchPattern)) {
av_log(s->ctx, AV_LOG_ERROR, "could not substitue fontconfig options.\n");
av_log(s->ctx, AV_LOG_ERROR, "could not substitute fontconfig options.\n");
FcPatternDestroy(pat);
FcConfigDestroy(fontconfig);
return AVERROR(ENOMEM);

View file

@ -898,7 +898,7 @@ typedef struct AVFilterParams {
char *instance_name;
/**
* Options to be apllied to the filter.
* Options to be applied to the filter.
*
* Filled by avfilter_graph_segment_parse(). Afterwards may be freely
* modified by the caller.
@ -1081,7 +1081,7 @@ int avfilter_graph_segment_init(AVFilterGraphSegment *seg, int flags);
* Unlabeled outputs are
* - linked to the first unlinked unlabeled input in the next non-disabled
* filter in the chain, if one exists
* - exported in the ouputs linked list otherwise, with NULL label
* - exported in the outputs linked list otherwise, with NULL label
*
* Similarly, unlinked input pads are exported in the inputs linked list.
*

View file

@ -1331,7 +1331,7 @@ static int get_output_ov(DNNModel *model, const char *input_name, int input_widt
#endif
ret = init_model_ov(ov_model, input_name, output_name ? &output_name : NULL, 1);
if (ret != 0) {
av_log(ctx, AV_LOG_ERROR, "Failed init OpenVINO exectuable network or inference request\n");
av_log(ctx, AV_LOG_ERROR, "Failed init OpenVINO executable network or inference request\n");
return ret;
}
}
@ -1487,7 +1487,7 @@ static int dnn_execute_model_ov(const DNNModel *model, DNNExecBaseParams *exec_p
ret = init_model_ov(ov_model, exec_params->input_name,
exec_params->output_names, exec_params->nb_output);
if (ret != 0) {
av_log(ctx, AV_LOG_ERROR, "Failed init OpenVINO exectuable network or inference request\n");
av_log(ctx, AV_LOG_ERROR, "Failed init OpenVINO executable network or inference request\n");
return ret;
}
}

View file

@ -508,7 +508,7 @@ int ff_inlink_check_available_frame(AVFilterLink *link);
/***
* Get the number of samples available on the link.
* @return the numer of samples available on the link.
* @return the number of samples available on the link.
*/
int ff_inlink_queued_samples(AVFilterLink *link);

View file

@ -41,7 +41,7 @@ typedef struct FFFramePool FFFramePool;
* @param width width of each frame in this pool
* @param height height of each frame in this pool
* @param format format of each frame in this pool
* @param align buffers alignement of each frame in this pool
* @param align buffers alignment of each frame in this pool
* @return newly created video frame pool on success, NULL on error.
*/
FFFramePool *ff_frame_pool_video_init(AVBufferRef* (*alloc)(size_t size),
@ -59,7 +59,7 @@ FFFramePool *ff_frame_pool_video_init(AVBufferRef* (*alloc)(size_t size),
* @param channels channels of each frame in this pool
* @param nb_samples number of samples of each frame in this pool
* @param format format of each frame in this pool
* @param align buffers alignement of each frame in this pool
* @param align buffers alignment of each frame in this pool
* @return newly created audio frame pool on success, NULL on error.
*/
FFFramePool *ff_frame_pool_audio_init(AVBufferRef* (*alloc)(size_t size),
@ -82,7 +82,7 @@ void ff_frame_pool_uninit(FFFramePool **pool);
* @param width width of each frame in this pool
* @param height height of each frame in this pool
* @param format format of each frame in this pool
* @param align buffers alignement of each frame in this pool
* @param align buffers alignment of each frame in this pool
* @return 0 on success, a negative AVERROR otherwise.
*/
int ff_frame_pool_get_video_config(FFFramePool *pool,
@ -97,7 +97,7 @@ int ff_frame_pool_get_video_config(FFFramePool *pool,
* @param channels channels of each frame in this pool
* @param nb_samples number of samples of each frame in this pool
* @param format format of each frame in this pool
* @param align buffers alignement of each frame in this pool
* @param align buffers alignment of each frame in this pool
* @return 0 on success, a negative AVERROR otherwise.
*/
int ff_frame_pool_get_audio_config(FFFramePool *pool,
@ -108,7 +108,7 @@ int ff_frame_pool_get_audio_config(FFFramePool *pool,
/**
* Allocate a new AVFrame, reussing old buffers from the pool when available.
* Allocate a new AVFrame, reusing old buffers from the pool when available.
* This function may be called simultaneously from multiple threads.
*
* @return a new AVFrame on success, NULL on error.

View file

@ -41,7 +41,7 @@ enum EOFAction {
* complex logic and a few user-tunable options.
*
* In this API, when a set of synchronized input frames is ready to be
* procesed is called a frame event. Frame event can be generated in
* processed is called a frame event. Frame event can be generated in
* response to input frames on any or all inputs and the handling of
* situations where some stream extend beyond the beginning or the end of
* others can be configured.
@ -76,9 +76,9 @@ enum FFFrameSyncExtMode {
};
/**
* Timestamp syncronization mode
* Timestamp synchronization mode
*
* Describe how the frames of a stream are syncronized based on timestamp
* Describe how the frames of a stream are synchronized based on timestamp
* distance.
*/
enum FFFrameTSSyncMode {

View file

@ -65,7 +65,7 @@ typedef struct QSVVPPContext {
mfxSession session;
int (*filter_frame) (AVFilterLink *outlink, AVFrame *frame); /**< callback */
int (*set_frame_ext_params)(AVFilterContext *ctx, const AVFrame *in, AVFrame *out, QSVVPPFrameParam *fp); /**< callbak */
int (*set_frame_ext_params)(AVFilterContext *ctx, const AVFrame *in, AVFrame *out, QSVVPPFrameParam *fp); /**< callback */
enum AVPixelFormat out_sw_format; /**< Real output format */
mfxVideoParam vpp_param;
mfxFrameInfo *frame_infos; /**< frame info for each input */
@ -110,7 +110,7 @@ typedef struct QSVVPPCrop {
typedef struct QSVVPPParam {
/* default is ff_filter_frame */
int (*filter_frame)(AVFilterLink *outlink, AVFrame *frame);
int (*set_frame_ext_params)(AVFilterContext *ctx, const AVFrame *in, AVFrame *out, QSVVPPFrameParam *fp); /**< callbak */
int (*set_frame_ext_params)(AVFilterContext *ctx, const AVFrame *in, AVFrame *out, QSVVPPFrameParam *fp); /**< callback */
/* To fill with MFX enhanced filter configurations */
int num_ext_buf;

View file

@ -1,5 +1,5 @@
/*
* Copyright (c) 2023 Institue of Software Chinese Academy of Sciences (ISCAS).
* Copyright (c) 2023 Institute of Software Chinese Academy of Sciences (ISCAS).
*
* This file is part of FFmpeg.
*

View file

@ -1,5 +1,5 @@
/*
* Copyright (c) 2023 Institue of Software Chinese Academy of Sciences (ISCAS).
* Copyright (c) 2023 Institute of Software Chinese Academy of Sciences (ISCAS).
*
* This file is part of FFmpeg.
*

View file

@ -176,7 +176,7 @@ int amf_setup_input_output_formats(AVFilterContext *avctx,
AVFilterFormats *input_formats;
AVFilterFormats *output_formats;
//in case if hw_device_ctx is set to DXVA2 we change order of pixel formats to set DXVA2 be choosen by default
//in case if hw_device_ctx is set to DXVA2 we change order of pixel formats to set DXVA2 be chosen by default
//The order is ignored if hw_frames_ctx is not NULL on the config_output stage
if (avctx->hw_device_ctx) {
AVHWDeviceContext *device_ctx = (AVHWDeviceContext*)avctx->hw_device_ctx->data;

View file

@ -28,7 +28,7 @@ extern "C"
* used float4 for better performance
*
* @param first_yuv first color vector
* @param second_yuv second color vecotr
* @param second_yuv second color vector
* @return answer of squared norm difference
*/
__device__ static inline float norm_squared(float4 first_yuv, float4 second_yuv)
@ -43,7 +43,7 @@ __device__ static inline float norm_squared(float4 first_yuv, float4 second_yuv)
* @brief calculate w as stated in bilateral filter research paper
*
* @param first_yuv first color vector
* @param second_yuv second color vecotr
* @param second_yuv second color vector
* @return the calculated w
*/
__device__ static inline float calculate_w(int x, int y, int r, int c,

View file

@ -1132,7 +1132,7 @@ fill_in_tongue(uint16_t* const pixels,
/* Scan the image line by line and fill the tongue outline
with the RGB values determined by the color system for the x-y
co-ordinates within the tongue.
coordinates within the tongue.
*/
for (y = 0; y < h; ++y) {

View file

@ -176,7 +176,7 @@ static int set_gauss(AVFilterContext *ctx)
/**
* Frees up buffers used by grey edge for storing derivatives final
* and intermidiate results. Number of buffers and number of planes
* and intermediate results. Number of buffers and number of planes
* for last buffer are given so it can be safely called at allocation
* failure instances.
*
@ -201,7 +201,7 @@ static void cleanup_derivative_buffers(ThreadData *td, int nb_buff, int nb_plane
/**
* Allocates buffers used by grey edge for storing derivatives final
* and intermidiate results.
* and intermediate results.
*
* @param ctx the filter context.
* @param td holds the buffers.
@ -236,12 +236,12 @@ static int setup_derivative_buffers(AVFilterContext* ctx, ThreadData *td)
/**
* Slice calculation of gaussian derivatives. Applies 1-D gaussian derivative filter
* either horizontally or vertically according to meta data given in thread data.
* When convoluting horizontally source is always the in frame withing thread data
* When convoluting horizontally source is always the in frame within thread data
* while when convoluting vertically source is a buffer.
*
* @param ctx the filter context.
* @param arg data to be passed between threads.
* @param jobnr current job nubmer.
* @param jobnr current job number.
* @param nb_jobs total number of jobs.
*
* @return 0.
@ -309,7 +309,7 @@ static int slice_get_derivative(AVFilterContext* ctx, void* arg, int jobnr, int
*
* @param ctx the filter context.
* @param arg data to be passed between threads.
* @param jobnr current job nubmer.
* @param jobnr current job number.
* @param nb_jobs total number of jobs.
*
* @return 0.
@ -430,7 +430,7 @@ static int get_derivative(AVFilterContext *ctx, ThreadData *td)
*
* @param ctx the filter context.
* @param arg data to be passed between threads.
* @param jobnr current job nubmer.
* @param jobnr current job number.
* @param nb_jobs total number of jobs.
*
* @return 0.
@ -479,7 +479,7 @@ static int filter_slice_grey_edge(AVFilterContext* ctx, void* arg, int jobnr, in
* Main control function for grey edge algorithm.
*
* @param ctx the filter context.
* @param in frame to perfrom grey edge on.
* @param in frame to perform grey edge on.
*
* @return 0 in case of success, a negative value corresponding to an
* AVERROR code in case of failure.
@ -558,7 +558,7 @@ static void normalize_light(double *light)
* after estimation.
*
* @param ctx the filter context.
* @param in frame to perfrom estimation on.
* @param in frame to perform estimation on.
*
* @return 0 in case of success, a negative value corresponding to an
* AVERROR code in case of failure.
@ -584,7 +584,7 @@ static int illumination_estimation(AVFilterContext *ctx, AVFrame *in)
*
* @param ctx the filter context.
* @param arg data to be passed between threads.
* @param jobnr current job nubmer.
* @param jobnr current job number.
* @param nb_jobs total number of jobs.
*
* @return 0.

View file

@ -352,7 +352,7 @@ static const AVOption convolution_opencl_options[] = {
{ "1m", "set matrix for 2nd plane", OFFSET(matrix_str[1]), AV_OPT_TYPE_STRING, {.str="0 0 0 0 1 0 0 0 0"}, 0, 0, FLAGS },
{ "2m", "set matrix for 3rd plane", OFFSET(matrix_str[2]), AV_OPT_TYPE_STRING, {.str="0 0 0 0 1 0 0 0 0"}, 0, 0, FLAGS },
{ "3m", "set matrix for 4th plane", OFFSET(matrix_str[3]), AV_OPT_TYPE_STRING, {.str="0 0 0 0 1 0 0 0 0"}, 0, 0, FLAGS },
{ "0rdiv", "set rdiv for 1nd plane", OFFSET(rdivs[0]), AV_OPT_TYPE_FLOAT, {.dbl=1.0}, 0.0, INT_MAX, FLAGS},
{ "0rdiv", "set rdiv for 1st plane", OFFSET(rdivs[0]), AV_OPT_TYPE_FLOAT, {.dbl=1.0}, 0.0, INT_MAX, FLAGS},
{ "1rdiv", "set rdiv for 2nd plane", OFFSET(rdivs[1]), AV_OPT_TYPE_FLOAT, {.dbl=1.0}, 0.0, INT_MAX, FLAGS},
{ "2rdiv", "set rdiv for 3rd plane", OFFSET(rdivs[2]), AV_OPT_TYPE_FLOAT, {.dbl=1.0}, 0.0, INT_MAX, FLAGS},
{ "3rdiv", "set rdiv for 4th plane", OFFSET(rdivs[3]), AV_OPT_TYPE_FLOAT, {.dbl=1.0}, 0.0, INT_MAX, FLAGS},

View file

@ -58,7 +58,7 @@ typedef struct CoreImageContext {
CFTypeRef *filters; ///< CIFilter object for all requested filters
int num_filters; ///< Amount of filters in *filters
char *output_rect; ///< Rectangle to be filled with filter intput
char *output_rect; ///< Rectangle to be filled with filter input
int list_filters; ///< Option used to list all available filters including generators
int list_generators; ///< Option used to list all available generators
} CoreImageContext;

View file

@ -493,7 +493,7 @@ static inline int interpolate_pchip(void *log_ctx, uint16_t *y,
goto end;
}
fi = xi + n; /* output values at inteval endpoints */
fi = xi + n; /* output values at interval endpoints */
di = fi + n; /* output slope wrt normalized input at interval endpoints */
hi = di + n; /* interval widths */
mi = hi + n - 1; /* linear slope over intervals */

View file

@ -81,7 +81,7 @@ static const AVOption dnn_detect_options[] = {
{ "cell_w", "cell width", OFFSET2(cell_w), AV_OPT_TYPE_INT, { .i64 = 0 }, 0, INTMAX_MAX, FLAGS },
{ "cell_h", "cell height", OFFSET2(cell_h), AV_OPT_TYPE_INT, { .i64 = 0 }, 0, INTMAX_MAX, FLAGS },
{ "nb_classes", "The number of class", OFFSET2(nb_classes), AV_OPT_TYPE_INT, { .i64 = 0 }, 0, INTMAX_MAX, FLAGS },
{ "anchors", "anchors, splited by '&'", OFFSET2(anchors), AV_OPT_TYPE_FLOAT | AV_OPT_TYPE_FLAG_ARRAY, { .arr = &anchor_array_def }, FLT_MIN, FLT_MAX, FLAGS },
{ "anchors", "anchors, split by '&'", OFFSET2(anchors), AV_OPT_TYPE_FLOAT | AV_OPT_TYPE_FLAG_ARRAY, { .arr = &anchor_array_def }, FLT_MIN, FLT_MAX, FLAGS },
{ NULL }
};

View file

@ -454,7 +454,7 @@ static const AVOption drawbox_options[] = {
{ "thickness", "set the box thickness", OFFSET(t_expr), AV_OPT_TYPE_STRING, { .str="3" }, 0, 0, FLAGS },
{ "t", "set the box thickness", OFFSET(t_expr), AV_OPT_TYPE_STRING, { .str="3" }, 0, 0, FLAGS },
{ "replace", "replace color & alpha", OFFSET(replace), AV_OPT_TYPE_BOOL, { .i64=0 }, 0, 1, FLAGS },
{ "box_source", "use datas from bounding box in side data", OFFSET(box_source_string), AV_OPT_TYPE_STRING, { .str=NULL }, 0, 1, FLAGS },
{ "box_source","use data from bounding box in side data", OFFSET(box_source_string), AV_OPT_TYPE_STRING, { .str=NULL }, 0, 1, FLAGS },
{ NULL }
};

View file

@ -562,7 +562,7 @@ static int load_font_fontconfig(AVFilterContext *ctx)
FcDefaultSubstitute(pat);
if (!FcConfigSubstitute(fontconfig, pat, FcMatchPattern)) {
av_log(ctx, AV_LOG_ERROR, "could not substitue fontconfig options"); /* very unlikely */
av_log(ctx, AV_LOG_ERROR, "could not substitute fontconfig options"); /* very unlikely */
FcPatternDestroy(pat);
return AVERROR(ENOMEM);
}
@ -866,7 +866,7 @@ static int func_pts(void *ctx, AVBPrint *bp, const char *function_name, unsigned
if (argc >= 3) {
if (!strcmp(fmt, "hms")) {
if (!strcmp(argv[2], "24HH")) {
av_log(ctx, AV_LOG_WARNING, "pts third argument 24HH is deprected, use pts:hms24hh instead\n");
av_log(ctx, AV_LOG_WARNING, "pts third argument 24HH is deprecated, use pts:hms24hh instead\n");
fmt = "hms24";
} else {
av_log(ctx, AV_LOG_ERROR, "Invalid argument '%s', '24HH' was expected\n", argv[2]);

View file

@ -463,7 +463,7 @@ static void row_fdct_c(int16_t *data, const uint8_t *pixels, ptrdiff_t line_size
tmp12 = tmp1 - tmp2;
//Even columns are written first, this leads to different order of columns
//in column_fidct(), but they are processed independently, so all ok.
//Later in the row_idct() columns readed at the same order.
//Later in the row_idct() columns are read in the same order.
dataptr[2] = tmp10 + tmp11;
dataptr[3] = tmp10 - tmp11;

View file

@ -1412,7 +1412,7 @@ static int libplacebo_config_output(AVFilterLink *outlink)
s->vkctx.output_width = outlink->w;
s->vkctx.output_height = outlink->h;
/* Default to re-using the input format */
/* Default to reusing the input format */
if (s->out_format == AV_PIX_FMT_NONE || s->out_format == AV_PIX_FMT_VULKAN) {
s->vkctx.output_format = s->vkctx.input_format;
} else {

View file

@ -208,7 +208,7 @@ static int filter_frame(AVFilterLink *inlink, AVFrame *cur)
av_frame_free(&decimate->ref);
decimate->ref = cur;
decimate->drop_count = FFMIN(-1, decimate->drop_count-1);
if (decimate->keep_count < 0) // re-enable counting similiar frames to ignore before dropping
if (decimate->keep_count < 0) // re-enable counting similar frames to ignore before dropping
decimate->keep_count = 0;
if ((ret = ff_filter_frame(outlink, av_frame_clone(cur))) < 0)

View file

@ -137,7 +137,7 @@ static int eval_expr(AVFilterContext *ctx)
var_values[VAR_OVERLAY_X] =
var_values[VAR_OX] = av_expr_eval(ox_expr, var_values, NULL);
/* calc overlay_w and overlay_h again incase relative to ox,oy */
/* calc overlay_w and overlay_h again in case relative to ox,oy */
var_values[VAR_OVERLAY_W] =
var_values[VAR_OW] = av_expr_eval(ow_expr, var_values, NULL);
var_values[VAR_OVERLAY_H] =

View file

@ -108,7 +108,7 @@ static int eval_expr(AVFilterContext *avctx)
var_values[VAR_OVERLAY_X] =
var_values[VAR_OX] = av_expr_eval(ox_expr, var_values, NULL);
/* calc overlay_w and overlay_h again incase relative to ox,oy */
/* calc overlay_w and overlay_h again in case relative to ox,oy */
var_values[VAR_OVERLAY_W] =
var_values[VAR_OW] = av_expr_eval(ow_expr, var_values, NULL);
var_values[VAR_OVERLAY_H] =

View file

@ -49,7 +49,7 @@
* remove rough edges, is stored in each pixel. This is done using an in-place
* erosion algorithm, and incrementing each pixel that survives any given
* erosion. Once every pixel is eroded, the maximum value is recorded, and a
* set of masks from size 0 to this size are generaged. The masks are circular
* set of masks from size 0 to this size are generated. The masks are circular
* binary masks, where each pixel within a radius N (where N is the size of the
* mask) is a 1, and all other pixels are a 0. Although a gaussian mask would be
* more mathematically accurate, a binary mask works better in practice because
@ -64,7 +64,7 @@
* condition is met (that the image function itself is continuous), even if the
* second boundary condition (that the derivative of the image function is
* continuous) is not met. A masking algorithm that does preserve the second
* boundary coundition (perhaps something based on a highly-modified bi-cubic
* boundary condition (perhaps something based on a highly-modified bi-cubic
* algorithm) should offer even better results on paper, but the noise in a
* typical TV signal should make anything based on derivatives hopelessly noisy.
*/

View file

@ -1,7 +1,7 @@
/*
* Copyright (c) 2010 Mark Heath mjpeg0 @ silicontrip dot org
* Copyright (c) 2014 Clément Bœsch
* Copyright (c) 2014 Dave Rice @dericed
* Copyright (c) 2014 Dave Rice
*
* This file is part of FFmpeg.
*
@ -304,7 +304,7 @@ static int filter8_tout(AVFilterContext *ctx, void *arg, int jobnr, int nb_jobs)
continue;
// detect two pixels above and below (to eliminate interlace artefacts)
// should check that video format is infact interlaced.
// should check that video format is in fact interlaced.
#define FILTER(i, j) \
filter_tout_outlier(p[(y-j) * lw + x + i], \
@ -352,7 +352,7 @@ static int filter16_tout(AVFilterContext *ctx, void *arg, int jobnr, int nb_jobs
continue;
// detect two pixels above and below (to eliminate interlace artefacts)
// should check that video format is infact interlaced.
// should check that video format is in fact interlaced.
if (y - 2 >= 0 && y + 2 < h) {
for (x = 1; x < w - 1; x++) {

View file

@ -581,7 +581,7 @@ static int request_frame(AVFilterLink *outlink)
StreamContext *sc, *sc2;
MatchingInfo match;
int i, j, ret;
int lookup = 1; /* indicates wheather EOF of all files is reached */
int lookup = 1; /* indicates whether EOF of all files is reached */
/* process all inputs */
for (i = 0; i < sic->nb_inputs; i++){

View file

@ -103,7 +103,7 @@ static av_cold void uninit(AVFilterContext *ctx)
static int config_input(AVFilterLink *inlink)
{
// Video input data avilable
// Video input data available
AVFilterContext *ctx = inlink->dst;
SiTiContext *s = ctx->priv;
int max_pixsteps[4];

View file

@ -38,7 +38,7 @@
/*
* @file
* Caculate the SSIM between two input 360 videos.
* Calculate the SSIM between two input 360 videos.
*/
#include <math.h>
@ -250,7 +250,7 @@ static const AVOption ssim360_options[] = {
OFFSET(ref_pad), AV_OPT_TYPE_FLOAT, {.dbl = .0f}, 0, 10, .flags = FLAGS },
{ "main_pad",
"Expansion (padding) coeffiecient for each cube face of the main video",
"Expansion (padding) coefficient for each cube face of the main video",
OFFSET(main_pad), AV_OPT_TYPE_FLOAT, {.dbl = .0f}, 0, 10, .flags = FLAGS },
{ "use_tape",

View file

@ -158,7 +158,7 @@ static int tonemap_opencl_init(AVFilterContext *avctx)
av_log(ctx, AV_LOG_DEBUG, "mapping range from %s to %s\n",
av_color_range_name(ctx->range_in),
av_color_range_name(ctx->range_out));
// checking valid value just because of limited implementaion
// checking valid value just because of limited implementation
// please remove when more functionalities are implemented
av_assert0(ctx->trc_out == AVCOL_TRC_BT709 ||
ctx->trc_out == AVCOL_TRC_BT2020_10);

View file

@ -410,7 +410,7 @@ static int config_input(AVFilterLink *inlink)
}
avctx_enc->strict_std_compliance = FF_COMPLIANCE_EXPERIMENTAL;
avctx_enc->global_quality = 123;
avctx_enc->thread_count = 1; // We do threading in the filter with muiltiple codecs
avctx_enc->thread_count = 1; // We do threading in the filter with multiple codecs
ret = avcodec_open2(avctx_enc, enc, &opts);
av_dict_free(&opts);
if (ret < 0)

View file

@ -648,7 +648,7 @@ static int graphs_build(AVFrame *in, AVFrame *out, const AVPixFmtDescriptor *des
alpha_src_format = s->alpha_src_format;
alpha_dst_format = s->alpha_dst_format;
/* The input slice is specified through the active_region field, unlike the output slice.
according to zimg requirements input and output slices should have even dimentions */
according to zimg requirements input and output slices should have even dimensions */
alpha_src_format.active_region.width = in->width;
alpha_src_format.active_region.height = in_slice_end - in_slice_start;
alpha_src_format.active_region.left = 0;

View file

@ -716,7 +716,7 @@ static int next_frame_internal(AVFilterContext *avctx, ID3D11Texture2D **desktop
goto error;
}
// Unforunately, we can't rely on the desktop_resource's format in this case.
// Unfortunately, we can't rely on the desktop_resource's format in this case.
// The API might even return it in with a format that was not in the initial
// list of supported formats, and it can change/flicker randomly.
// To work around this, return an internal copy of the last valid texture we got.

View file

@ -87,7 +87,7 @@ ALIGN 16
mov [frameantq+xq*2], t0w
movifnidn dstq, dstmp
%if %1 != 16
shr t0d, 16-%1 ; could eliminate this by storing from t0h, but only with some contraints on register allocation
shr t0d, 16-%1 ; could eliminate this by storing from t0h, but only with some constraints on register allocation
%endif
%if %1 == 8
mov [dstq+xq], t0b